@@ -9,8 +9,8 @@ looping forever.
 
 import time
 
-import rx
-from rx import operators as ops
+import reactivex
+from reactivex import operators as ops
 
 
 def failing(x):
@@ -21,16 +21,13 @@ def failing(x):
 
 
 def main():
-    xs = rx.from_marbles("1-2-3-4-5-6-7-9-|").pipe(ops.publish())
-    xs.pipe(
-        ops.map(failing),
-        ops.retry()
-    ).subscribe(print)
+    xs = reactivex.from_marbles("1-2-3-4-5-6-7-9-|").pipe(ops.publish())
+    xs.pipe(ops.map(failing), ops.retry()).subscribe(print)
 
     xs.connect()  # Must connect. Cannot use ref_count() with publish()
 
     time.sleep(5)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
