@@ -1,5 +1,5 @@
 import unittest
-from datetime import datetime
+from datetime import datetime, timezone
 
 from reactivex import operators as ops
 from reactivex.testing import ReactiveTest, TestScheduler
@@ -30,7 +30,9 @@ class TestTakeUntilWithTime(unittest.TestCase):
         )
 
         def create():
-            return xs.pipe(ops.take_until_with_time(datetime.utcfromtimestamp(0)))
+            return xs.pipe(
+                ops.take_until_with_time(datetime.fromtimestamp(0, tz=timezone.utc))
+            )
 
         res = scheduler.start(create)
 
@@ -44,7 +46,7 @@ class TestTakeUntilWithTime(unittest.TestCase):
         )
 
         def create():
-            dt = datetime.utcfromtimestamp(250)
+            dt = datetime.fromtimestamp(250, tz=timezone.utc)
             return xs.pipe(ops.take_until_with_time(dt))
 
         res = scheduler.start(create)
@@ -58,7 +60,7 @@ class TestTakeUntilWithTime(unittest.TestCase):
         xs = scheduler.create_hot_observable(on_error(210, ex))
 
         def create():
-            dt = datetime.utcfromtimestamp(250)
+            dt = datetime.fromtimestamp(250, tz=timezone.utc)
             return xs.pipe(ops.take_until_with_time(dt))
 
         res = scheduler.start(create)
@@ -71,7 +73,7 @@ class TestTakeUntilWithTime(unittest.TestCase):
         xs = scheduler.create_hot_observable()
 
         def create():
-            dt = datetime.utcfromtimestamp(250)
+            dt = datetime.fromtimestamp(250, tz=timezone.utc)
             return xs.pipe(ops.take_until_with_time(dt))
 
         res = scheduler.start(create)
@@ -92,8 +94,8 @@ class TestTakeUntilWithTime(unittest.TestCase):
         )
 
         def create():
-            dt235 = datetime.utcfromtimestamp(235)
-            dt255 = datetime.utcfromtimestamp(255)
+            dt235 = datetime.fromtimestamp(235, tz=timezone.utc)
+            dt255 = datetime.fromtimestamp(255, tz=timezone.utc)
             return xs.pipe(
                 ops.take_until_with_time(dt255),
                 ops.take_until_with_time(dt235),
@@ -122,8 +124,8 @@ class TestTakeUntilWithTime(unittest.TestCase):
         )
 
         def create():
-            dt235 = datetime.utcfromtimestamp(235)
-            dt255 = datetime.utcfromtimestamp(255)
+            dt235 = datetime.fromtimestamp(235, tz=timezone.utc)
+            dt255 = datetime.fromtimestamp(255, tz=timezone.utc)
             return xs.pipe(
                 ops.take_until_with_time(dt235),
                 ops.take_until_with_time(dt255),
