@@ -1,5 +1,5 @@
 import unittest
-from datetime import datetime
+from datetime import datetime, timezone
 
 from reactivex import operators as ops
 from reactivex.testing import ReactiveTest, TestScheduler
@@ -241,7 +241,9 @@ class TestTimeout(unittest.TestCase):
         ys = scheduler.create_cold_observable(on_next(100, -1))
 
         def create():
-            return xs.pipe(ops.timeout(datetime.utcfromtimestamp(400), ys))
+            return xs.pipe(
+                ops.timeout(datetime.fromtimestamp(400, tz=timezone.utc), ys)
+            )
 
         results = scheduler.start(create)
 
@@ -255,7 +257,9 @@ class TestTimeout(unittest.TestCase):
         ys = scheduler.create_cold_observable(on_next(100, -1))
 
         def create():
-            return xs.pipe(ops.timeout(datetime.utcfromtimestamp(400), ys))
+            return xs.pipe(
+                ops.timeout(datetime.fromtimestamp(400, tz=timezone.utc), ys)
+            )
 
         results = scheduler.start(create)
 
@@ -270,7 +274,9 @@ class TestTimeout(unittest.TestCase):
         ys = scheduler.create_cold_observable(on_next(100, -1))
 
         def create():
-            return xs.pipe(ops.timeout(datetime.utcfromtimestamp(400), ys))
+            return xs.pipe(
+                ops.timeout(datetime.fromtimestamp(400, tz=timezone.utc), ys)
+            )
 
         results = scheduler.start(create)
 
@@ -286,7 +292,9 @@ class TestTimeout(unittest.TestCase):
         ys = scheduler.create_cold_observable(on_next(100, -1))
 
         def create():
-            return xs.pipe(ops.timeout(datetime.utcfromtimestamp(400), ys))
+            return xs.pipe(
+                ops.timeout(datetime.fromtimestamp(400, tz=timezone.utc), ys)
+            )
 
         results = scheduler.start(create)
 
@@ -302,7 +310,9 @@ class TestTimeout(unittest.TestCase):
         ys = scheduler.create_cold_observable()
 
         def create():
-            return xs.pipe(ops.timeout(datetime.utcfromtimestamp(400), ys))
+            return xs.pipe(
+                ops.timeout(datetime.fromtimestamp(400, tz=timezone.utc), ys)
+            )
 
         results = scheduler.start(create)
 
