@@ -1,5 +1,5 @@
 import unittest
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 from reactivex.internal.constants import UTC_ZERO
 from reactivex.scheduler import HistoricalScheduler
@@ -20,7 +20,9 @@ def assert_equals(first, second):
 
 
 def time(days):
-    dt = datetime(year=1979, month=10, day=31, hour=4, minute=30, second=15)
+    dt = datetime(
+        year=1979, month=10, day=31, hour=4, minute=30, second=15, tzinfo=timezone.utc
+    )
     dt = dt + timedelta(days=days)
     return dt
 
